==> brobygger-li-2.3.2.tar.gz: brobygger-li-2.3.2/scraper/linkedin/connections_in_org/items.py <==
"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/8/20
"""
# Standard library imports
# Related third party imports
# Import local applications
import scraper.scraping_tools as mt


def get_mutual_connections_info(soup):
    """
    Returns:
        a list of dictionaries with the following {keys: values}
            full_name   : str, default None
            headline    : str, default None
            li_per_url  : str, default None


    """
    info = mt.get_info(soup, {
        'full_name': 'span.entity-result__title-text  span span',
        "dist_value": ".image-text-lockup__text",
        'headline': '.entity-result__primary-subtitle',
        'location': '.entity-result__secondary-subtitle'

    })
    if info['dist_value'] is not None:
        info['dist_value'] = info['dist_value'].strip("• ")
    info['url'] = mt.get_attribute_value(soup, 'span.entity-result__title-text a', "href")
    if info['url'] is not None:
        info['url'] = mt.validate_link_one(info['url'])
    # if info['url'] is not None:
    #     info['url'] = "https://www.linkedin.com" + info['url']

    # info['mutual_connections_url'] = mt.get_attribute_value(soup, 'div[data-entity-action-type="SEE_MUTUAL_CONNECTIONS"]', "href")
    # if info['mutual_connections_url'] is not None:
    #     info['mutual_connections_url'] = "https://www.linkedin.com" + info['mutual_connections_url']
    #
    # mutual_connections = soup.select('a.search-result__social-proof-connection-name')
    # info['mutual_connections'] = []
    # for c in mutual_connections:
    #     try:
    #         link = c["href"]
    #     except:
    #         link = None
    #     if link is not None:
    #         info['mutual_connections'].append("https://www.linkedin.com" + link)
    return [info]

==> brobygger-li-2.5.1.tar.gz: brobygger-li-2.5.1/scraper/linkedin/connections_in_org/items.py <==
"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/8/20
"""
# Standard library imports
# Related third party imports
# Import local applications
import scraper.scraping_tools as mt


def get_mutual_connections_info(soup):
    """
    Returns:
        a list of dictionaries with the following {keys: values}
            full_name   : str, default None
            headline    : str, default None
            li_per_url  : str, default None


    """
    info = mt.get_info(soup, {
        'full_name': 'span.entity-result__title-text  span span',
        "dist_value": ".image-text-lockup__text span",
        'headline': '.entity-result__primary-subtitle',
        'location': '.entity-result__secondary-subtitle',
        'mutual_connections': 'span.entity-result__simple-insight-text',

    })
    if info['dist_value'] is not None:
        info['dist_value'] = info['dist_value'].strip("• ")
    info['url'] = mt.get_attribute_value(soup, 'span.entity-result__title-text a', "href")
    if info['url'] is not None:
        info['url'] = mt.validate_link_one(info['url'])
    icon_type = mt.get_attribute_value(soup, "li-icon", "type")
    if icon_type == "linkedin-bug":
        info.update({"premium": "True"})
    else:
        info.update({"premium": "False"})

    info['mutual_connections_url'] = mt.get_attribute_value(soup, 'div.entity-result__simple-insight-text-container a:last-child', "href")

    #
    # mutual_connections = soup.select('a.search-result__social-proof-connection-name')
    # info['mutual_connections'] = []
    # for c in mutual_connections:
    #     try:
    #         link = c["href"]
    #     except:
    #         link = None
    #     if link is not None:
    #         info['mutual_connections'].append("https://www.linkedin.com" + link)
    return [info]
